<!DOCTYPE TS><TS>
<context>
    <name>QObject</name>
    <message>
        <source>element</source>
        <comment>1</comment>
        <translation>элемент</translation>
    </message>
    <message>
        <source>elements</source>
        <comment>2-4</comment>
        <translation>элемента</translation>
    </message>
    <message>
        <source>elements</source>
        <comment>5+</comment>
        <translation>элементов</translation>
    </message>
    <message>
        <source>item</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>items</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>items</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>complex item is not shown</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>page</source>
        <comment>1</comment>
        <translation>страница</translation>
    </message>
    <message>
        <source>pages</source>
        <comment>2-4</comment>
        <translation>страницы</translation>
    </message>
    <message>
        <source>pages</source>
        <comment>5+</comment>
        <translation>страниц</translation>
    </message>
    <message>
        <source>parameter</source>
        <comment>1</comment>
        <translation>параметр</translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>2-4</comment>
        <translation>параметра</translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>5+</comment>
        <translation>параметров</translation>
    </message>
    <message>
        <source>child</source>
        <comment>1</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>childs</source>
        <comment>2-4</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>childs</source>
        <comment>5+</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delinearization failed!</source>
        <translation>Делинеаризация не удалась!</translation>
    </message>
    <message>
        <source>Input file &apos;%1&apos; does not exist</source>
        <translation>Входящий файл &apos;%1&apos; не существует</translation>
    </message>
    <message>
        <source>Input and output files must be different</source>
        <translation>Входящий и исходящий файл должны быть разными</translation>
    </message>
    <message>
        <source>Delinearized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delinearize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add item to dictionary</source>
        <translation>Добавить запись в словарь</translation>
    </message>
    <message>
        <source>Add element to array</source>
        <translation>Добавить элемент в массив</translation>
    </message>
    <message>
        <source>Set color</source>
        <translation type="unfinished">Установить цвет</translation>
    </message>
    <message>
        <source>Set font properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set relative position of a single operator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set relative position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <translation type="unfinished">Установить стиль пунктира линии</translation>
    </message>
    <message>
        <source>Set line width</source>
        <translation type="unfinished">Установить толщину линии</translation>
    </message>
    <message>
        <source>View page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add system font</source>
        <translation>Добавить системный шрифт</translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <translation>Извлечь текст из страницы</translation>
    </message>
    <message>
        <source>Set page tranformation matrix</source>
        <translation>Установить матрицу преобразования страницы</translation>
    </message>
    <message>
        <source>Draw line</source>
        <translation>Нарисовать линию</translation>
    </message>
    <message>
        <source>Draw rect</source>
        <translation>Нарисовать прямоугольник</translation>
    </message>
    <message>
        <source>Add text</source>
        <translation>Добавить текст</translation>
    </message>
    <message>
        <source>Remove page</source>
        <translation>Удалить страницу</translation>
    </message>
    <message>
        <source>Show all operators</source>
        <translation>Показать все операторы</translation>
    </message>
    <message>
        <source>Show only text operators</source>
        <translation>Показать только текстовые операторы</translation>
    </message>
    <message>
        <source>Show only font operators</source>
        <translation>Показать только шрифтовые операторы</translation>
    </message>
    <message>
        <source>Show only graphical operators</source>
        <translation>Показать только графические операторы</translation>
    </message>
    <message>
        <source>Move one level up</source>
        <translation>Сместить на уровень выше</translation>
    </message>
    <message>
        <source>Move one level down</source>
        <translation>Сместить на уровень ниже</translation>
    </message>
    <message>
        <source>Save page as image</source>
        <translation>Сохранить страницу как изображение</translation>
    </message>
    <message>
        <source>Save selected area as image</source>
        <translation>Сохранить выбранную область как изображение</translation>
    </message>
    <message>
        <source>Changed revision to:</source>
        <translation>Сохранить версию в:</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Использование:</translation>
    </message>
    <message>
        <source>input file</source>
        <translation>входящий файл</translation>
    </message>
    <message>
        <source>output file</source>
        <translation>исходящий файл</translation>
    </message>
    <message>
        <source>Input file must exist</source>
        <translation>Должен существовать входящий файл</translation>
    </message>
    <message>
        <source>Output file must not exist</source>
        <translation>Исходящий файл не должен существовать</translation>
    </message>
    <message>
        <source>is expecting two parameters</source>
        <translation>ожидает два параметра</translation>
    </message>
    <message>
        <source>Output file &apos;%1&apos; already exist</source>
        <translation>Исходящий файл &apos;%1&apos; уже существует</translation>
    </message>
    <message>
        <source>position</source>
        <translation>положение</translation>
    </message>
    <message>
        <source>No page selected!</source>
        <translation>Ни одна страница не выбрана!</translation>
    </message>
    <message>
        <source>Page rotated.</source>
        <translation>Страница повёрнута.</translation>
    </message>
    <message>
        <source>Change page rectangle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Изменить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <source>Page metrics</source>
        <translation>Метрики страницы</translation>
    </message>
    <message>
        <source>Left upper corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>x position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>y position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right bottom corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MediaBox changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No page or operator selected!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Selected operator</source>
        <translation>Выбранный оператор</translation>
    </message>
    <message>
        <source>is not</source>
        <translation>не</translation>
    </message>
    <message>
        <source>suitable for colour setting.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please see the pdf specification for details.</source>
        <translation>Ознакомьтесь со спецификацией на PDF.</translation>
    </message>
    <message>
        <source>changeable</source>
        <translation>изменяем</translation>
    </message>
    <message>
        <source>Colour changed</source>
        <translation>Цвет изменился</translation>
    </message>
    <message>
        <source>for</source>
        <translation>для</translation>
    </message>
    <message>
        <source>operators</source>
        <translation>операторов</translation>
    </message>
    <message>
        <source>suitable for line width change.</source>
        <translation>подходит для смены толщины линии.</translation>
    </message>
    <message>
        <source>Line width changed.</source>
        <translation>Толщина линии изменена.</translation>
    </message>
    <message>
        <source>suitable for dash style change.</source>
        <translation>подходит для смены стиля пунктира.</translation>
    </message>
    <message>
        <source>Change line dash pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line dashing patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Solid line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slightly dashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dot and dashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dash pattern changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 added to page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>text operator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only text operators allowed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator %1 is not changeable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Добавить шрифт</translation>
    </message>
    <message>
        <source>Add system fonts</source>
        <translation>Добавить системный шрифт</translation>
    </message>
    <message>
        <source>Avaliable system fonts</source>
        <translation>Доступные системные шрифты</translation>
    </message>
    <message>
        <source>Select system Type1 font</source>
        <translation>Выберите системный шрифт Type1</translation>
    </message>
    <message>
        <source>System font added.</source>
        <translation>Системный шрифт добавлен.</translation>
    </message>
    <message>
        <source>Text on page</source>
        <translation>Текст на странице</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>Text extracted from page</source>
        <translation>Текст, извлечённый из страницы</translation>
    </message>
    <message>
        <source>Text on a page.</source>
        <translation>Текст на странице.</translation>
    </message>
    <message>
        <source>Page text displayed</source>
        <translation>Отображён текст страницы</translation>
    </message>
    <message>
        <source>Add page transformation matrix</source>
        <translation>Добавить матрицу преобразования страницы</translation>
    </message>
    <message>
        <source>Change page transformation matrix</source>
        <translation>Изменить матрицу преобразования страницы</translation>
    </message>
    <message>
        <source>Page transformation matrix description</source>
        <translation>Оисание матрицы преобразования страницы</translation>
    </message>
    <message>
        <source>Page transformation description</source>
        <translation>Оисание преобразования страницы</translation>
    </message>
    <message>
        <source>Select which transformations to use</source>
        <translation>Выберите используемые типы преобразования</translation>
    </message>
    <message>
        <source>Translate (shift) page</source>
        <translation>Смещение страницы</translation>
    </message>
    <message>
        <source>Scale page</source>
        <translation>Масштабирование страницы</translation>
    </message>
    <message>
        <source>Skew page</source>
        <translation>Перекашивание страницы</translation>
    </message>
    <message>
        <source>Page translation</source>
        <translation>Смещение</translation>
    </message>
    <message>
        <source>Set values</source>
        <translation>Укажите значения</translation>
    </message>
    <message>
        <source>Page scaling</source>
        <translation>Масштабирование</translation>
    </message>
    <message>
        <source>Page skewing</source>
        <translation>Перекашивание</translation>
    </message>
    <message>
        <source>Invalid number supplied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page transformation matrix changed to </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change relative text operator position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change relative text position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relative operator position (this is not absolute position)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not find text positioning.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator position changed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relative operator position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X and Y position must be a number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line was drawn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rect was drawn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search text</source>
        <translation>Искать текст</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Искать</translation>
    </message>
    <message>
        <source>Text :</source>
        <translation>Текст:</translation>
    </message>
    <message>
        <source>Find what</source>
        <translation>Что искать</translation>
    </message>
    <message>
        <source>On currently viewed page only</source>
        <translation>Только на просматриваемой сейчас странице</translation>
    </message>
    <message>
        <source>Nothing was found.</source>
        <translation>Ничего не найдено.</translation>
    </message>
    <message>
        <source>Dictionary has no type!</source>
        <translation>У словаря нет типа!</translation>
    </message>
    <message>
        <source>Maybe bad stream!</source>
        <translation>Возможно запорчен поток!</translation>
    </message>
    <message>
        <source>%1 is requirement for %2, but not found for it !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>For child %1 of %2 is requirement %3 subchild, but has %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available functions:</source>
        <translation>Доступные функции:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Описание</translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <source>No function found matching &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too many function found matching &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Matching functions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>function name</source>
        <translation>имя функции</translation>
    </message>
    <message>
        <source>function parameter(s)</source>
        <translation>параметр(ы) функции</translation>
    </message>
    <message>
        <source>First parameter is name of function to invoke (case insensitive) or its unambiguous part.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rest of parameters are passed to invoked function.</source>
        <translation>Остальные параметры передаются вызванной функции.</translation>
    </message>
    <message>
        <source>New revision of document created</source>
        <translation>Создана новая версия документа</translation>
    </message>
    <message>
        <source>Saving as</source>
        <translation type="obsolete">Сохраняется как</translation>
    </message>
    <message>
        <source>Warning: This document is linearized PDF!</source>
        <translation>Предупреждение: документ является линеаризованным PDF!</translation>
    </message>
    <message>
        <source>Warning: This document is encrypted!</source>
        <translation>Предупреждение: документ зашифрован!</translation>
    </message>
    <message>
        <source>Encryption filter:</source>
        <translation type="obsolete">Фильтр шифрования:</translation>
    </message>
    <message>
        <source>Encrypted content will show up as garbage and many operations will be impossible</source>
        <translation type="obsolete">Зашифрованное содержимое будет отображено неподобающе, и многие операции будет невозможно выполнить</translation>
    </message>
    <message>
        <source>Error occured while loading file</source>
        <translation>Ошибка при загрузке файла</translation>
    </message>
    <message>
        <source>Text saved to %1</source>
        <translation>Текст сохранён в %1</translation>
    </message>
    <message>
        <source>Save as text file</source>
        <translation>Сохранить как текстовый файл</translation>
    </message>
    <message>
        <source>Image was not saved!</source>
        <translation>Изображение не сохранено!</translation>
    </message>
    <message>
        <source>out of range</source>
        <translation>вне диапазона</translation>
    </message>
    <message>
        <source>Operator cm must have array with 6 numbers as parameter!</source>
        <translation>У оператора cm должен быть массив с цифрой 6 в качестве параметра!</translation>
    </message>
    <message>
        <source>Matrix is in bad state !</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have 1 parameter, but has %2 !</source>
        <translation>У оператора &apos;%1&apos; должен быть 1 параметр, а вместо этого — %2!</translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have %2 parameters, but has %3 !</source>
        <translation>У оператора &apos;%1&apos; должно быть %2 параметров, а вместо этого — %3!</translation>
    </message>
    <message>
        <source>Operator must be</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Must define color</source>
        <translation>Необходимо определить цвет</translation>
    </message>
    <message>
        <source>r,g,b must be number</source>
        <translation>r,g,b должны быть числом</translation>
    </message>
    <message>
        <source>r,g,b must be from 0 to 255</source>
        <translation>r,g,b должны быть в диапазоне от 0 до 255</translation>
    </message>
    <message>
        <source>No preceding font operator found...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid operand type</source>
        <translation>Некорректный тип операнда</translation>
    </message>
    <message>
        <source>Page parameter must be defined!</source>
        <translation>Должен быть определён параметр страницы!</translation>
    </message>
    <message>
        <source>This option is not supported.</source>
        <translation>Этот параметр не поддерживается.</translation>
    </message>
    <message>
        <source>&amp;Add object</source>
        <translation>&amp;Добавить объект</translation>
    </message>
    <message>
        <source>Add and c&amp;lose</source>
        <translation>Добавить и &amp;закрыть</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>О&amp;тменить</translation>
    </message>
    <message>
        <source>Overwrite?</source>
        <translation>&amp;Перезаписать?</translation>
    </message>
    <message>
        <source>Document is read-only</source>
        <translation>Документ в режиме «Только чтение»</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;ОК</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Применить</translation>
    </message>
    <message>
        <source>Open file ...</source>
        <translation>Открыть файл...</translation>
    </message>
    <message>
        <source>PDF files (*.pdf)</source>
        <translation>Файлы PDF (*.pdf)</translation>
    </message>
    <message>
        <source>File called &quot;%1&quot; already exists. Do you want to overwrite it?</source>
        <translation>Файл с именем &quot;%1&quot; уже существует. Вы хотите его перезаписать?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Да</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Нет</translation>
    </message>
    <message>
        <source>Save file as ...</source>
        <translation>Сохранить файл как...</translation>
    </message>
    <message>
        <source>xml files (*.xml)</source>
        <translation>Файлы XML (*.xml)</translation>
    </message>
    <message>
        <source>Pick a file ...</source>
        <translation>Выберите файл...</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <source>&amp;Up</source>
        <translation>&amp;Выше</translation>
    </message>
    <message>
        <source>&amp;Down</source>
        <translation>&amp;Ниже</translation>
    </message>
    <message>
        <source>&amp;Index</source>
        <translation>&amp;Содержание</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>&lt;no name&gt;</source>
        <translation>&lt;без имени&gt;</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Страница</translation>
    </message>
    <message>
        <source>Dictionary</source>
        <translation>Словарь</translation>
    </message>
    <message>
        <source>Stream</source>
        <translation>Поток</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>Аннотация</translation>
    </message>
    <message>
        <source>List</source>
        <translation>Список</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation>Каталог</translation>
    </message>
    <message>
        <source>Content Stream</source>
        <translation>Поток содержимого</translation>
    </message>
    <message>
        <source>Showing all</source>
        <comment>mode</comment>
        <translation>Показываются все</translation>
    </message>
    <message>
        <source>Showing text. op.</source>
        <comment>mode</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showing font. op.</source>
        <comment>mode</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Showing graphic. op.</source>
        <comment>mode</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parameter</source>
        <translation>Параметр</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Оператор</translation>
    </message>
    <message>
        <source>Operators</source>
        <translation>Операторы</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Аннотации</translation>
    </message>
    <message>
        <source>Invalid operation</source>
        <translation>Некорректная операция</translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Null</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bool</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Int</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Real</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>String</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <comment>Type name</comment>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Ref</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Array</source>
        <comment>Type name</comment>
        <translation>Массив</translation>
    </message>
    <message>
        <source>Dict</source>
        <comment>Type name</comment>
        <translation>Словарь</translation>
    </message>
    <message>
        <source>Stream</source>
        <comment>Type name</comment>
        <translation>Поток</translation>
    </message>
    <message>
        <source>DebugCmd</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DebugError</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DebugEOF</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DebugNone</source>
        <comment>Type name</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>байт</translation>
    </message>
    <message>
        <source>Fatal Error</source>
        <translation>Критическая ошибка</translation>
    </message>
    <message>
        <source>Invalid %1 in config:
Name: %2
Data: %3
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected: </source>
        <translation>Ожидалось: </translation>
    </message>
    <message>
        <source>Missing item in config</source>
        <translation>Отсутствующий предмет в конфиге</translation>
    </message>
    <message>
        <source>menu definition</source>
        <translation>определение меню</translation>
    </message>
    <message>
        <source>Menu items list</source>
        <translation>Список пунктов меню</translation>
    </message>
    <message>
        <source>Cycle in menu detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>menu item</source>
        <translation>пункт меню</translation>
    </message>
    <message>
        <source>2 or more parameters in item definition</source>
        <translation>2 или более параметров в определении предмета</translation>
    </message>
    <message>
        <source>toolbar item</source>
        <translation>объект панели инструментов</translation>
    </message>
    <message>
        <source>4 parameters in item definition</source>
        <translation>4 параметра в определении предмета</translation>
    </message>
    <message>
        <source>label item</source>
        <translation>объект «метка»</translation>
    </message>
    <message>
        <source>toolbar definition</source>
        <translation>определение панели</translation>
    </message>
    <message>
        <source>Options: </source>
        <translation>Параметры: </translation>
    </message>
    <message>
        <source>Parameter missing for option : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid commandline option : </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>option(s)</source>
        <translation>параметр(ов)</translation>
    </message>
    <message>
        <source>files(s)</source>
        <translation>файл(ов)</translation>
    </message>
    <message>
        <source>Print help and exit</source>
        <translation>Показать справку и выйти</translation>
    </message>
    <message>
        <source>Print version and exit</source>
        <translation>Показать номер версии и выйти</translation>
    </message>
    <message>
        <source>Set debug messages verbosity</source>
        <translation>Установить подробность вывода отладочных сообщений</translation>
    </message>
    <message>
        <source>(n = -1 .. 5)</source>
        <translation>(n = -1 .. 5)</translation>
    </message>
    <message>
        <source>Run in commandline mode</source>
        <translation>Запустить в режиме командной строки</translation>
    </message>
    <message>
        <source>file</source>
        <translation>файл</translation>
    </message>
    <message>
        <source>Run script from script path or current directory if not found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run script from current directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Evaluate script code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop processing options</source>
        <translation>Остановить обработку параметров</translation>
    </message>
    <message>
        <source>Font face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font size (in points)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line width (in points)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use &apos;%1 --help&apos; to see list of commandline options and their parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved as</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to open file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not implemented: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply from page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>How many pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flattening failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flattened</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No pages in document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Operation not implemented: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter password for %1:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>annotation_type</name>
    <message>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Ссылка</translation>
    </message>
    <message>
        <source>FreeText</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Квадрат</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>Круг</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Многоугольник</translation>
    </message>
    <message>
        <source>PolyLine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Подчёркивание</translation>
    </message>
    <message>
        <source>Squiggly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StrikeOut</source>
        <translation>Зачёркивание</translation>
    </message>
    <message>
        <source>Stamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Caret</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ink</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Popup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fileattachement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Звук</translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Фильм</translation>
    </message>
    <message>
        <source>Widget</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Printermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trapnet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Водяной знак</translation>
    </message>
    <message>
        <source>3D</source>
        <translation>3D</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестно</translation>
    </message>
</context>
<context>
    <name>gui::AboutWindow</name>
    <message>
        <source>About program</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Free program for PDF document manipulation</source>
        <translation>Свободная программа для редактирования PDF</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Домашняя страница</translation>
    </message>
    <message>
        <source>Project page</source>
        <translation>Страница проекта</translation>
    </message>
    <message>
        <source>Compiled</source>
        <translation>Сборка</translation>
    </message>
    <message>
        <source>Using Qt %1</source>
        <translation>С использованием Qt %1</translation>
    </message>
    <message>
        <source>, QSA %1</source>
        <translation>, QSA %1</translation>
    </message>
    <message>
        <source>This program is distributed under terms of GNU GPL</source>
        <translation>Эта программа распространяется на условиях GNU GPL</translation>
    </message>
</context>
<context>
    <name>gui::AddItemDialog</name>
    <message>
        <source>Add object</source>
        <translation type="unfinished">Добавить объект</translation>
    </message>
    <message>
        <source>Type and value of new object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New empty Dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New empty Array</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Append to end</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No object type selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Entered property is not valid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name of new property must be specified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reference target does not exist!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; already exist as %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; added to dictionary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property added to position %1 in array</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Array index %1 out of range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Property added to end of array</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::AnnotDialog</name>
    <message>
        <source>Add new annotation</source>
        <translation>Добавка новой аннотации</translation>
    </message>
    <message>
        <source>Text Annotation</source>
        <translation>Текстовая аннотация</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Содержимое</translation>
    </message>
    <message>
        <source>Icon &amp;Name</source>
        <translation>Имя &amp;значка</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NewParagraph</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примечание</translation>
    </message>
    <message>
        <source>Paragraph</source>
        <translation>Абзац</translation>
    </message>
    <message>
        <source>&amp;State</source>
        <translation>&amp;Состояние</translation>
    </message>
    <message>
        <source>Marked</source>
        <translation>Маркировано</translation>
    </message>
    <message>
        <source>Unmarked</source>
        <translation>Не маркировано</translation>
    </message>
    <message>
        <source>State &amp;Model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Review</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Text Annotation</source>
        <translation>&amp;Текстовая аннотация</translation>
    </message>
    <message>
        <source>&amp;Destination</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Highlight mode</source>
        <translation>&amp;Режим подсветки</translation>
    </message>
    <message>
        <source>N - None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>I - Invert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>O - Outline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>P - Push</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Link Annotation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Base</name>
    <message>
        <source>Error running</source>
        <translation>Ошибка при запуске</translation>
    </message>
    <message>
        <source>Script not found</source>
        <translation>Сценарий не найден</translation>
    </message>
    <message>
        <source>No init script found - check your configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Looked for</source>
        <comment>scripts</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Предупреждение</translation>
    </message>
    <message>
        <source>Flattening of encrypted documents is not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown error occured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delinearization of encrypted documents is not supported</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::BaseCore</name>
    <message>
        <source>Error in callback handler: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exception in callback handler: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown exception in script occured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exception in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid object given for parameter %1 in </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected</source>
        <comment>object type</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Got</source>
        <comment>object type</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::BaseGUI</name>
    <message>
        <source>No document opened</source>
        <translation>Ни один документ не открыт</translation>
    </message>
    <message>
        <source>You must pick a different file than &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::ColorTool</name>
    <message>
        <source>Choose color</source>
        <translation>Выбрать цвет</translation>
    </message>
    <message>
        <source>Foreground</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Background</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::HelpWindow</name>
    <message>
        <source>help</source>
        <translation>справка</translation>
    </message>
</context>
<context>
    <name>gui::MergeDialog</name>
    <message>
        <source>Open file with pages to be inserted</source>
        <translation>Открыть файл со вставляемыми страницами</translation>
    </message>
    <message>
        <source>Insert pages from another document</source>
        <translation>Вставить страницы из другого документа</translation>
    </message>
    <message>
        <source>&amp;Filename</source>
        <translation>&amp;Имя файла</translation>
    </message>
    <message>
        <source>END</source>
        <comment>end of document marker</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::MultiTreeWindow</name>
    <message>
        <source>Tree</source>
        <translation>Дерево</translation>
    </message>
    <message>
        <source>Document tree</source>
        <translation>Дерево документа</translation>
    </message>
    <message>
        <source>Close current tab</source>
        <translation>Закрыть эту вкладку</translation>
    </message>
    <message>
        <source>Switch to ...</source>
        <translation>Переключиться на...</translation>
    </message>
</context>
<context>
    <name>gui::OptionWindow</name>
    <message>
        <source>options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Редактор</translation>
    </message>
    <message>
        <source>Advanced mode</source>
        <translation>Расширенный режим</translation>
    </message>
    <message>
        <source>Turning on advanced mode will allow more powerful (but also more dangerous) changes to edited document.</source>
        <translation>Включение расширенного режима позволит вносить более серьёзные, но и более опасные изменения в документ.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Advanced mode will affect only newly opened files</source>
        <translation>&lt;b&gt;Примечание&lt;/b&gt;: включение и отключение расширенного режима повлияет только на открытые впоследствии файлы</translation>
    </message>
    <message>
        <source>Show hidden properties</source>
        <translation>Показывать скрытые свойства</translation>
    </message>
    <message>
        <source>Allow editing read-only properties</source>
        <translation>Разрешить правку свойств в режиме «Только чтение»</translation>
    </message>
    <message>
        <source>Remember path of last opened/saved file</source>
        <translation>Запоминать путь к последним открывавшимся/сохранявшимся документам</translation>
    </message>
    <message>
        <source>Length units</source>
        <translation>Единицы измерения длины</translation>
    </message>
    <message>
        <source>Character encoding</source>
        <translation>Кодировка символов</translation>
    </message>
    <message>
        <source>Paths</source>
        <translation>Пути</translation>
    </message>
    <message>
        <source>You can use environment variables (for example $HOME) in settings on this page</source>
        <translation>Вы можете использовать переменные окружения  (например, $HOME) в параметрах этой страницы</translation>
    </message>
    <message>
        <source>Icon Path</source>
        <translation>Путь к значкам</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Icon Path will take effect on next program start</source>
        <translation>&lt;b&gt;Примечание&lt;/b&gt;: смена пути к значкам возымеет эффект при следующем запуске программы</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>Путь к сценариям</translation>
    </message>
    <message>
        <source>Scripts to run on start</source>
        <translation>Сценарии для запуска при старте</translation>
    </message>
    <message>
        <source>Console log file</source>
        <translation>Журнальный файл консоли</translation>
    </message>
    <message>
        <source>Object tree</source>
        <translation>Дерево объектов</translation>
    </message>
    <message>
        <source>These objects will be shown in the object tree</source>
        <translation>Эти объекты будут отображены в дереве объектов</translation>
    </message>
    <message>
        <source>Document dictionary</source>
        <translation>Словарь документа</translation>
    </message>
    <message>
        <source>Object dictionaries</source>
        <translation>Словари объектов</translation>
    </message>
    <message>
        <source>Graphic objects</source>
        <translation>Графические объекты</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Аннотации</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Страницы</translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation>Контуры</translation>
    </message>
    <message>
        <source>Content Streams</source>
        <translation>Потоки содержимого</translation>
    </message>
    <message>
        <source>Simple Objects</source>
        <translation>Простые объекты</translation>
    </message>
    <message>
        <source>Options affecting object tree and property editor</source>
        <translation>Параметры, влияющие на дерево объектов и редактор свойств</translation>
    </message>
    <message>
        <source>Sort dictionary items alphabetically</source>
        <translation>Располагать записи словаря в алфавитном порядке</translation>
    </message>
    <message>
        <source>Commandline</source>
        <translation>Командная строка</translation>
    </message>
    <message>
        <source>Commandline options</source>
        <translation>Параметры командой строки</translation>
    </message>
    <message>
        <source>Show return value of executed scripts in console</source>
        <translation>Показывать в консоли значение, возвращённое выполненными сценариями</translation>
    </message>
    <message>
        <source>Show return value also for complex types
(possibly long output)</source>
        <translation>Показывать возвращённое значение и для сложных типов (возможен длинный вывод)</translation>
    </message>
    <message>
        <source>Show errors from event handlers</source>
        <translation>Показывать ошибки от обработчиков событий</translation>
    </message>
    <message>
        <source>Show command editor</source>
        <translation>Показывать редактор команд</translation>
    </message>
    <message>
        <source>Show command line</source>
        <translation>Показывать командную строку</translation>
    </message>
    <message>
        <source>Editable command line</source>
        <translation>Редактируемая командная строка</translation>
    </message>
    <message>
        <source>History options</source>
        <translation>Параметры истории</translation>
    </message>
    <message>
        <source>History file</source>
        <translation>Файл истории</translation>
    </message>
    <message>
        <source>Max. lines in history</source>
        <translation>Макс. строк в истории</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Панели</translation>
    </message>
    <message>
        <source>These toolbars will be shown:</source>
        <translation>Эти панели будут показаны:</translation>
    </message>
    <message>
        <source>Look and Feel</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <source>You can set fonts used in application</source>
        <translation>Вы можете указать используемые в программе шрифты</translation>
    </message>
    <message>
        <source>Application font</source>
        <translation>Шрифт интерфейса</translation>
    </message>
    <message>
        <source>Console font</source>
        <translation>Шрифт консоли</translation>
    </message>
    <message>
        <source>Statusbar font</source>
        <translation>Шрифт статусной строки</translation>
    </message>
    <message>
        <source>You can specify overall visual style</source>
        <translation>Вы можете указать общий стиль оформления</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Стиль</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Тема значков</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing icon theme will take effect on next program start</source>
        <translation>&lt;b&gt;Примечание&lt;/b&gt;: смена темы значков возымеет эффект при следующем запуске программы</translation>
    </message>
    <message>
        <source>Use big icons</source>
        <translation>Использовать большие значки</translation>
    </message>
    <message>
        <source>Page view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initial focus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will specify which part of editor window will receive keyboard focus when new window is opened</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::PageSpace</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 из %2</translation>
    </message>
    <message>
        <source>Save as image ...</source>
        <translation>Сохранить как изображение...</translation>
    </message>
</context>
<context>
    <name>gui::PasswordDialog</name>
    <message>
        <source>Enter password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::PdfEditWindow</name>
    <message>
        <source>Selection</source>
        <translation>Выделение</translation>
    </message>
    <message>
        <source>Selected operators</source>
        <translation>Выделенные операторы</translation>
    </message>
    <message>
        <source>Selected annotations</source>
        <translation>Выделенные анотации</translation>
    </message>
    <message>
        <source>Current file is not saved. Do you want to save it?</source>
        <translation>Текущий файл не сохранён. Хотите сохранить его?</translation>
    </message>
    <message>
        <source>No document to save</source>
        <translation>Нет сохраняемого документа</translation>
    </message>
    <message>
        <source>Name is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document is in read-only mode</source>
        <translation>Документ в режиме «Только чтение»</translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation>При сохранении документа произошла неизвестная ошибка</translation>
    </message>
    <message>
        <source>Error occured while saving copy</source>
        <translation type="obsolete">При сохранении копии произошла неизвестная ошибка</translation>
    </message>
    <message>
        <source>viewing revision</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation type="unfinished">Линеаризованный PDF</translation>
    </message>
    <message>
        <source>Encrypted</source>
        <translation>Зашифрованный</translation>
    </message>
    <message>
        <source>Error while loading document </source>
        <translation>Ошибка при загрузке документа </translation>
    </message>
    <message>
        <source>Unknown error while loading document </source>
        <translation>Неизвестная ошибка при загрузке документа </translation>
    </message>
    <message>
        <source>Loaded file</source>
        <translation>Загружен файл</translation>
    </message>
    <message>
        <source>Saving not implemented:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error occured while saving copy:
%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password entered for document is not valid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::Property</name>
    <message>
        <source>Read only</source>
        <translation>Только чтение</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Расширенный</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation>Скрытый</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Неизвестный</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Обычный</translation>
    </message>
</context>
<context>
    <name>gui::PropertyEditor</name>
    <message>
        <source>No object selected</source>
        <translation>Ни один объект не выбран</translation>
    </message>
    <message>
        <source>This %1 is empty</source>
        <translation>Этот %1 пуст</translation>
    </message>
    <message>
        <source>dictionary</source>
        <comment>property type</comment>
        <translation>словарь</translation>
    </message>
    <message>
        <source>This %1 does not have any directly editable properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>stream</source>
        <comment>property type</comment>
        <translation>поток</translation>
    </message>
    <message>
        <source>This array is empty</source>
        <translation>Этот массив пуст</translation>
    </message>
    <message>
        <source>This array does not have any directly editable elements</source>
        <translation>У этого потока нет напрямую изменяемых элементов</translation>
    </message>
    <message>
        <source>This type of object does not have any properties</source>
        <translation>У объектов этого типа не бывает свойств</translation>
    </message>
    <message>
        <source>This operator does not have any parameters</source>
        <translation>У этого оператора нет параметров</translation>
    </message>
    <message>
        <source>This operator does not have any directly editable parameters</source>
        <translation>У этого оператора нет напрямую изменяемых элементов</translation>
    </message>
</context>
<context>
    <name>gui::QSPage</name>
    <message>
        <source>Invalid operation</source>
        <translation>Некорректный оператор</translation>
    </message>
    <message>
        <source>Out of range</source>
        <translation>Вне диапазона</translation>
    </message>
    <message>
        <source>Unknown exception</source>
        <translation>Неизвестное прерывание</translation>
    </message>
</context>
<context>
    <name>gui::QSPdf</name>
    <message>
        <source>Document is in read-only mode</source>
        <translation>Документ в режиме «Только чтение»</translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation>При сохранении документа произошла неизвестная ошибка</translation>
    </message>
    <message>
        <source>Page not found</source>
        <translation>Страница не найдена</translation>
    </message>
    <message>
        <source>Unable to save:
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::RefPropertyDialog</name>
    <message>
        <source>Reference target</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose target for indirect reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Object number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generation number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reference target is not valid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::RevisionTool</name>
    <message>
        <source>Revision: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>байт</translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation>Линеаризованный PDF</translation>
    </message>
    <message>
        <source>No revisions</source>
        <translation>Без версий</translation>
    </message>
</context>
<context>
    <name>gui::SelectPagesDialog</name>
    <message>
        <source>Convert pdf to xml</source>
        <translation>Преобразовать PDF в XML</translation>
    </message>
</context>
<context>
    <name>gui::Settings</name>
    <message>
        <source>Main Toolbar</source>
        <comment>MainToolbar</comment>
        <translation>Основная панель</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <comment>fload</comment>
        <translation>&amp;Открыть...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <comment>fsave</comment>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <comment>opts</comment>
        <translation>&amp;Параметры</translation>
    </message>
    <message>
        <source>Close Window</source>
        <comment>closew</comment>
        <translation>Закрыть окно</translation>
    </message>
    <message>
        <source>Show/Hide &amp;commandline</source>
        <comment>hideCmd</comment>
        <translation>Показать/скрыть &amp;командную строку</translation>
    </message>
    <message>
        <source>Page Toolbar</source>
        <comment>PageToolbar</comment>
        <translation>Панель страниц</translation>
    </message>
    <message>
        <source>Reload Page</source>
        <comment>reloadpage</comment>
        <translation type="obsolete">Перезагрузить страницу</translation>
    </message>
    <message>
        <source>Rotate page 270 degrees</source>
        <comment>rot-90</comment>
        <translation>Повернуть страницу на 270°</translation>
    </message>
    <message>
        <source>Rotate page 90 degrees</source>
        <comment>rot90</comment>
        <translation>Повернуть страницу на 90°</translation>
    </message>
    <message>
        <source>Edit page metrics</source>
        <comment>editPageMediaBox</comment>
        <translation>Изменить метрики страницы</translation>
    </message>
    <message>
        <source>Add system font to page</source>
        <comment>addSystemFont</comment>
        <translation>Добавить системный шрифт к странице</translation>
    </message>
    <message>
        <source>Set page transformation matrix</source>
        <comment>setpagetm</comment>
        <translation>Установить матрицу преобразования страницы</translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <comment>pagetext</comment>
        <translation>Извлечь текст из страницы</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <comment>zoom_out</comment>
        <translation>&amp;Отдалить</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <comment>zoom_in</comment>
        <translation>&amp;Приблизить</translation>
    </message>
    <message>
        <source>Move page up</source>
        <comment>pageMoveUp</comment>
        <translation>Переместить страницу выше</translation>
    </message>
    <message>
        <source>Move page down</source>
        <comment>pageMoveDown</comment>
        <translation>Переместить страницу ниже</translation>
    </message>
    <message>
        <source>Remove page</source>
        <comment>pageRemove</comment>
        <translation>Удалить страницу</translation>
    </message>
    <message>
        <source>Draw Toolbar</source>
        <comment>DrawToolbar</comment>
        <translation>Панель рисования</translation>
    </message>
    <message>
        <source>Draw line</source>
        <comment>drawlinee</comment>
        <translation>Нарисовать линию</translation>
    </message>
    <message>
        <source>Draw arrow</source>
        <comment>drawarrowe</comment>
        <translation>Нарисовать стрелку</translation>
    </message>
    <message>
        <source>Draw rectangle</source>
        <comment>drawrecte</comment>
        <translation>Нарисовать прямоугольник</translation>
    </message>
    <message>
        <source>Add text</source>
        <comment>addtext</comment>
        <translation>Добавить текст</translation>
    </message>
    <message>
        <source>Strike through</source>
        <comment>striketrough</comment>
        <translation>Перечеркнуть</translation>
    </message>
    <message>
        <source>Highlighting text</source>
        <comment>highlightingtext</comment>
        <translation>Подсветка текста</translation>
    </message>
    <message>
        <source>Revision Toolbar</source>
        <comment>RevisionToolbar</comment>
        <translation>Панель версий</translation>
    </message>
    <message>
        <source>Revisions</source>
        <comment>revlabel</comment>
        <translation>Версии</translation>
    </message>
    <message>
        <source>Operator Toolbar</source>
        <comment>OperatorToolbar</comment>
        <translation>Панель операторов</translation>
    </message>
    <message>
        <source>Set color</source>
        <comment>opsetcolor</comment>
        <translation>Установить цвет</translation>
    </message>
    <message>
        <source>Set font</source>
        <comment>opsetfont</comment>
        <translation>Установить шрифт</translation>
    </message>
    <message>
        <source>Set line width</source>
        <comment>opsetlinewidth</comment>
        <translation>Установить толщину линии</translation>
    </message>
    <message>
        <source>Selection mode Toolbar</source>
        <comment>SelectionModeToolbar</comment>
        <translation>Панель режимов выделения</translation>
    </message>
    <message>
        <source>Select all objects</source>
        <comment>selectAllObjects</comment>
        <translation>&amp;Выбирать все объекты</translation>
    </message>
    <message>
        <source>Select graphical operators</source>
        <comment>selectGraphical</comment>
        <translation>Выбирать &amp;графические операторы</translation>
    </message>
    <message>
        <source>Select text</source>
        <comment>selectText</comment>
        <translation>Выбирать &amp;текст</translation>
    </message>
    <message>
        <source>Select annotations</source>
        <comment>selectAnnot</comment>
        <translation>Выбирать &amp;аннотации</translation>
    </message>
    <message>
        <source>Text Toolbar</source>
        <comment>TextToolBar</comment>
        <translation>Панель текста</translation>
    </message>
    <message>
        <source>TreeView Toolbar</source>
        <comment>TreeViewToolbar</comment>
        <translation>Панель дерева документа</translation>
    </message>
    <message>
        <source>Add object</source>
        <comment>treeAdditem</comment>
        <translation>Добавить объект</translation>
    </message>
    <message>
        <source>Delete object</source>
        <comment>treeDelitem</comment>
        <translation>Удалить объект</translation>
    </message>
    <message>
        <source>PageRider Toolbar</source>
        <comment>PageRiderToolbar</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First Page</source>
        <comment>firstpage</comment>
        <translation>Первая страница</translation>
    </message>
    <message>
        <source>Prev Page</source>
        <comment>prevpage</comment>
        <translation>Предыдущая страница</translation>
    </message>
    <message>
        <source>Next Page</source>
        <comment>nextpage</comment>
        <translation>Следующая страница</translation>
    </message>
    <message>
        <source>Last Page</source>
        <comment>lastpage</comment>
        <translation>Последняя страница</translation>
    </message>
    <message>
        <source>Dynamic Toolbar</source>
        <comment>DynamicToolBar</comment>
        <translation>Динамическая панель инструментов</translation>
    </message>
    <message>
        <source>Show all operators in stream</source>
        <comment>streamAll</comment>
        <translation>Показывать все операторы в потоке</translation>
    </message>
    <message>
        <source>Show only text operators in stream</source>
        <comment>streamText</comment>
        <translation>Показывать только текстовые операторы в потоке</translation>
    </message>
    <message>
        <source>Show only font operators in stream</source>
        <comment>streamFont</comment>
        <translation>Показывать только шрифтовые операторы в потоке</translation>
    </message>
    <message>
        <source>Show only graphical operators in stream</source>
        <comment>streamGfx</comment>
        <translation>Показывать только графические операторы в потоке</translation>
    </message>
    <message>
        <source>Main menu</source>
        <comment>MainMenu</comment>
        <translation>Главное меню</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <comment>filemenu</comment>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Save &amp;copy...</source>
        <comment>fsavecopy</comment>
        <translation type="obsolete">Сохранить &amp;копию...</translation>
    </message>
    <message>
        <source>Save new &amp;revision</source>
        <comment>fsaverev</comment>
        <translation>Сохранить новую &amp;версию</translation>
    </message>
    <message>
        <source>Save as text...</source>
        <comment>fsaveastext</comment>
        <translation>Сохранить как текст...</translation>
    </message>
    <message>
        <source>New &amp;Window</source>
        <comment>neww</comment>
        <translation>&amp;Новое окно</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <comment>quit</comment>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <comment>showmenu</comment>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>Show/Hide &amp;property editor</source>
        <comment>hideProp</comment>
        <translation>Показать/скрыть &amp;редактор свойств</translation>
    </message>
    <message>
        <source>Show/Hide object &amp;tree</source>
        <comment>hideTree</comment>
        <translation>Показать/скрыть &amp;дерево объектов</translation>
    </message>
    <message>
        <source>Show/Hide &amp;status bar</source>
        <comment>hideStatus</comment>
        <translation>Показать/скрыть &amp;статусную строку</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <comment>searchText</comment>
        <translation>&amp;Искать текст</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <comment>toolsmenu</comment>
        <translation>С&amp;ервис</translation>
    </message>
    <message>
        <source>&amp;Insert Pages from other document</source>
        <comment>mergeDoc</comment>
        <translation>&amp;Вставить страницы из другого документа</translation>
    </message>
    <message>
        <source>&amp;Page</source>
        <comment>pagemenu</comment>
        <translation>Стр&amp;аница</translation>
    </message>
    <message>
        <source>Save page as image...</source>
        <comment>savepage</comment>
        <translation>Сохранить страницу как изображение...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <comment>editopersmenu</comment>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>Set relative position of operator</source>
        <comment>opsetposop</comment>
        <translation>Установить относительное положение оператора</translation>
    </message>
    <message>
        <source>Change relative position</source>
        <comment>opsetpos</comment>
        <translation>Изменить относительное положение</translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <comment>opsetdash</comment>
        <translation>Установить стиль пунктира линии</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>helpmenu</comment>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <comment>help_about</comment>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>help_index</comment>
        <translation>&amp;Содержание</translation>
    </message>
    <message>
        <source>Reload Page (show changes)</source>
        <comment>reloadpage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Copy current revision</source>
        <comment>fcopyrevision</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>gui::TreeItemPdf</name>
    <message>
        <source>Pages</source>
        <translation>Страницы</translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation>Контуры</translation>
    </message>
</context>
<context>
    <name>gui::TreeWindow</name>
    <message>
        <source>Object</source>
        <translation>Объект</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Данные</translation>
    </message>
</context>
<context>
    <name>gui::Units</name>
    <message>
        <source>point</source>
        <translation>пункт</translation>
    </message>
    <message>
        <source>pt : point</source>
        <translation>pt : пункт</translation>
    </message>
    <message>
        <source>inch</source>
        <translation>дюйм</translation>
    </message>
    <message>
        <source>inches</source>
        <translation>дюймы</translation>
    </message>
    <message>
        <source>in : inch</source>
        <translation>in : дюйм</translation>
    </message>
    <message>
        <source>mil : milli-inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hands</source>
        <translation>руки</translation>
    </message>
    <message>
        <source>hand</source>
        <translation>рука</translation>
    </message>
    <message>
        <source>hand : hand</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>foot</source>
        <translation>фут</translation>
    </message>
    <message>
        <source>feet</source>
        <translation>футов</translation>
    </message>
    <message>
        <source>ft : foot</source>
        <translation>ft : фут</translation>
    </message>
    <message>
        <source>link</source>
        <translation></translation>
    </message>
    <message>
        <source>links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>li : link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>yard</source>
        <translation>ярд</translation>
    </message>
    <message>
        <source>yards</source>
        <translation>ярды</translation>
    </message>
    <message>
        <source>yd : yard</source>
        <translation>yd : ярд</translation>
    </message>
    <message>
        <source>rod</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>rods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pole</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>poles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>perch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>perches</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>rd : rod (pole, perch)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fathom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fathoms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fm. : fathom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>chains</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ch : chain</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>furlong</source>
        <translation>фурлонг</translation>
    </message>
    <message>
        <source>furlongs</source>
        <translation>фурлонги</translation>
    </message>
    <message>
        <source>fur. : furlong</source>
        <translation>fur. : фурлонг</translation>
    </message>
    <message>
        <source>cable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cable : cable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mile</source>
        <translation>миля</translation>
    </message>
    <message>
        <source>miles</source>
        <translation>мили</translation>
    </message>
    <message>
        <source>mi : mile</source>
        <translation>mi : миля</translation>
    </message>
    <message>
        <source>land</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>lands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>league</source>
        <translation>лига</translation>
    </message>
    <message>
        <source>leagues</source>
        <translation>лиги</translation>
    </message>
    <message>
        <source>land : land (league)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>m : meter</source>
        <translation>m : метр</translation>
    </message>
    <message>
        <source>Ym : yottameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zm : zettameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Em : exameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pm : petameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tm : terameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gm : gigameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mm : megameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>km : kilometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hm : hectometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dam : decameter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>dm : decimeter</source>
        <translation>dm : дециметр</translation>
    </message>
    <message>
        <source>cm : centimeter</source>
        <translation>cm : сантиметр</translation>
    </message>
    <message>
        <source>mm : millimeter</source>
        <translation>mm : миллиметр</translation>
    </message>
    <message>
        <source>um : micrometer</source>
        <translation>um : микрометр</translation>
    </message>
    <message>
        <source>nm : nanometer</source>
        <translation>nm : нанометр</translation>
    </message>
    <message>
        <source>pm : picometer</source>
        <translation>pm : пикометр</translation>
    </message>
    <message>
        <source>fm : femtometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>am : attometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zm : zeptometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ym : yoctometer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A : angstrom</source>
        <translation>A : ангстрем</translation>
    </message>
    <message>
        <source>astronomical unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>astronomical units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AU : astronomical unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>light year</source>
        <translation>световой год</translation>
    </message>
    <message>
        <source>light years</source>
        <translation>световых лет</translation>
    </message>
    <message>
        <source>ly : light year</source>
        <translation>ly : световой год</translation>
    </message>
    <message>
        <source>parsec</source>
        <translation>парсек</translation>
    </message>
    <message>
        <source>pc : parsec</source>
        <translation>pc : парсек</translation>
    </message>
    <message>
        <source>nautical mile</source>
        <translation>морская миля</translation>
    </message>
    <message>
        <source>nautical miles</source>
        <translation>морские мили</translation>
    </message>
    <message>
        <source>n.m. : nautical mile</source>
        <translation>n.m. : морская миля</translation>
    </message>
</context>
</TS>
